==> qutim_0.2.60-maemo-13.tar.gz: qutim-0.2.60-maemo/translations/bg_BG/vkontakte.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vkontakteplugin.cpp" line="+32"/>
        <source>Aleksey Sidorov</source>
        <translation>Алексей Сидоров</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/photoalbum/vphotoalbumplugin.cpp" line="+17"/>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="+17"/>
        <source>Alexey Sidorov</source>
        <translation>Алексей Сидоров</translation>
    </message>
</context>
<context>
    <name>ContactInfo</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vinforequest.cpp" line="+52"/>
        <source>Nickname</source>
        <translation>Псевдоним</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>First name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Last name</source>
        <translation>Фамилия</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gender</source>
        <translation>Пол</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Birthday</source>
        <translation>Роден</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>City</source>
        <translation>Град</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Country</source>
        <translation>Държава</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Photo</source>
        <translation>Снимка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Home phone</source>
        <translation>Телефон (дом.)</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vcontact.cpp" line="+187"/>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vinforequest.cpp" line="+1"/>
        <source>Mobile phone</source>
        <translation>Телефон (моб.)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Activity</source>
        <translation>Дейност</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vinforequest.cpp" line="+1"/>
        <source>University</source>
        <translation>Университет</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Faculty</source>
        <translation>Факултет</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Graduation year</source>
        <translation>Година на завършване</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Undefined</source>
        <translation>Незададен</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Female</source>
        <translation>Жена</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Male</source>
        <translation>Мъж</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>General</source>
        <translation>Обща</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Person</source>
        <translation>Човек</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Home address</source>
        <translation>Домашен адрес</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Education</source>
        <translation>Образование</translation>
    </message>
</context>
<context>
    <name>ContactList</name>
    <message>
        <source>Activity</source>
        <translation type="obsolete">Дейност</translation>
    </message>
</context>
<context>
    <name>EdditAccount</name>
    <message>
        <source>Editing %1</source>
        <translation type="obsolete">Редактиране на %1</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="obsolete">Настройки на сметка</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="obsolete">Общи</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="obsolete">Парола:</translation>
    </message>
    <message>
        <source>Autoconnect on start</source>
        <translation type="obsolete">Автоматично свързване при стартиране</translation>
    </message>
    <message>
        <source>Keep-alive every:</source>
        <translation type="obsolete">Поддържане връзката на всеки:</translation>
    </message>
    <message>
        <source> s</source>
        <translation type="obsolete"> &quot;</translation>
    </message>
    <message>
        <source>Refresh friend list every:</source>
        <translation type="obsolete">Обновяване на списъка с приятели на всеки:</translation>
    </message>
    <message>
        <source>Check for new messages every:</source>
        <translation type="obsolete">Проверка за ново съобщение на всеки:</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation type="obsolete">Актуализации</translation>
    </message>
    <message>
        <source>Check for friends updates every:</source>
        <translation type="obsolete">Проверка за актуализации на приятелите на всеки:</translation>
    </message>
    <message>
        <source>Enable friends photo updates notifications</source>
        <translation type="obsolete">Известяване за актуализации в снимките на приятелите</translation>
    </message>
    <message>
        <source>Insert preview URL on new photos notifications</source>
        <translation type="obsolete">Вмъкване на предварителен преглед на URL при известие за нова снимка</translation>
    </message>
    <message>
        <source>Insert fullsize URL on new photos notifications</source>
        <translation type="obsolete">Вмъкване на пълно-размерен преглед на URL при известие за нова снимка</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">ОК</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">Прилагане</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Отказ</translation>
    </message>
    <message>
        <source>Show status text in contact list</source>
        <translation type="obsolete">Показване на текста на статуса в списъка с контакти</translation>
    </message>
</context>
<context>
    <name>LoginForm</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Настройки на сметка</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="obsolete">E-mail:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="obsolete">Парола:</translation>
    </message>
    <message>
        <source>Autoconnect on start</source>
        <translation type="obsolete">Автоматично свързване при стартиране</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vkontakteplugin.cpp" line="-3"/>
        <source>Vkontakte</source>
        <translation>ВКонтакте</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Simple implementation of vkontakte, based on userapi.ru</source>
        <translation>Опростена реализация на ВКонтакте, на базата на userapi.ru</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>vkontakte</source>
        <translation>ВКонтакте</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Simple implementation of vkontakte, based on desktop.api</source>
        <translation>Опростена реализация на ВКонтакте, на базата на desktop.api</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Vkontakte account creator</source>
        <translation>Създаване на ВКонтакте сметка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Account creator for Vkontakte</source>
        <translation>Създаване на сметка за ВКонтакте</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Proxy support</source>
        <translation>Поддръжка на прокси</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proxy support for Vkontakte</source>
        <translation>Поддръжка на прокси във ВКонтакте</translation>
    </message>
    <message>
        <source>Userapi</source>
        <translation type="obsolete">Userapi</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="-3"/>
        <source>Wall</source>
        <translation>Стена</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vkontakte wall support for qutIM</source>
        <translation>Поддръжка на ВКонтакте стена в qutIM</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/photoalbum/vphotoalbumplugin.cpp" line="-3"/>
        <source>Photoalbum</source>
        <translation>Фото албум</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vkontakte photoalbum support for qutIM</source>
        <translation>Поддръжка на ВКонтакте фото албум в qutIM</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="+3"/>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="+3"/>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vkontakteplugin.cpp" line="-18"/>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
</context>
<context>
    <name>VAccountSettings</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/ui/vaccountsettings.ui" line="+14"/>
        <source>Account settings</source>
        <translation>Настройки на сметката</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Password:</source>
        <translation>Парола:</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/ui/vaccountsettings.cpp" line="+42"/>
        <source>%1 settings</source>
        <translation>%1 настройки</translation>
    </message>
</context>
<context>
    <name>VAccountWizardPage</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/ui/vaccountwizardpage.ui" line="+14"/>
        <source>WizardPage</source>
        <translation>Създаване на сметка</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Email:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Password:</source>
        <translation>Парола:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Save password</source>
        <translation>Запис на паролата</translation>
    </message>
</context>
<context>
    <name>VConnection</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vconnection.cpp" line="+89"/>
        <source>qutIM - VKontakte authorization</source>
        <translation>qutIM -ВКонтакте удостоверяване</translation>
    </message>
</context>
<context>
    <name>VConnectionPrivate</name>
    <message>
        <source>Error! (TODO)</source>
        <translation type="obsolete">Грешка</translation>
    </message>
</context>
<context>
    <name>VRosterPrivate</name>
    <message>
        <source>Friends</source>
        <translation type="obsolete">Приятели</translation>
    </message>
</context>
<context>
    <name>VWallSession</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/wall/vwallsession.cpp" line="+42"/>
        <source>%1 (Wall)</source>
        <translation>%1 (Стена)</translation>
    </message>
</context>
<context>
    <name>VWallSessionPrivate</name>
    <message>
        <location line="+129"/>
        <source>Unknown</source>
        <translation>Неизвестен</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Audio</source>
        <translation>Звуков</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Application</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Graffiti</source>
        <translation>Графити</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Photo</source>
        <translation>Снимка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Posted photo</source>
        <translation>Публикува снимка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Multimedia message: %1</source>
        <translation>Мултимедийно съобщение: %1</translation>
    </message>
</context>
<context>
    <name>VcontactList</name>
    <message>
        <source>Friends</source>
        <translation type="obsolete">Приятели</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="obsolete">Любими</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;2&apos;&gt;&lt;b&gt;Status message:&lt;/b&gt;&amp;nbsp;%1&lt;/font</source>
        <translation type="obsolete">&lt;font size=&apos;2&apos;&gt;&lt;b&gt;Съобщение на статуса:&lt;/b&gt;&amp;nbsp;%1&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Open user page</source>
        <translation type="obsolete">Отваряне страницата на потребителя</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;2&apos;&gt;&lt;b&gt;Status message:&lt;/b&gt;%1&lt;/font</source>
        <translation type="obsolete">&lt;font size=&apos;2&apos;&gt;&lt;b&gt;Съобщение на статуса:&lt;/b&gt;%1&lt;/font&gt;</translation>
    </message>
</context>
<context>
    <name>Vkontakte</name>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vkontakteprotocol.cpp" line="+77"/>
        <source>Open homepage</source>
        <translation>Отваряне страницата</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="+9"/>
        <source>View wall</source>
        <translation>Преглед на всички</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vkontakteplugin.cpp" line="+21"/>
        <source>Account settings</source>
        <translation>Настройки на сметката</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/plugins/photoalbum/vphotoalbumplugin.cpp" line="+10"/>
        <source>View photoalbum</source>
        <translation>Преглед на фото албума</translation>
    </message>
</context>
<context>
    <name>VkontakteProtocol</name>
    <message>
        <source>Email</source>
        <translation type="obsolete">Email</translation>
    </message>
    <message>
        <source>email</source>
        <translation type="obsolete">Email</translation>
    </message>
    <message>
        <location filename="../../qutim-meta/protocols/vkontakte/src/vkontakteprotocol.cpp" line="+27"/>
        <source>id</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VkontakteProtocolPrivate</name>
    <message>
        <location line="+29"/>
        <source>Send sms</source>
        <translation>Изпращане на SMS</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>text:</source>
        <translation>текст:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>sms</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>VprotocolWrap</name>
    <message>
        <source>Mismatch nick or password</source>
        <translation type="obsolete">Псевдонимът или паролата не съвпадат</translation>
    </message>
    <message>
        <source>Vkontakte.ru updates</source>
        <translation type="obsolete">Vkontakte.ru актуализации</translation>
    </message>
    <message>
        <source>%1 was tagged on photo</source>
        <translation type="obsolete">%1 бе отбелязан(а) на снимка</translation>
    </message>
    <message>
        <source>%1 added new photo</source>
        <translation type="obsolete">%1 е добавил(а) нова снимка</translation>
    </message>
</context>
<context>
    <name>VstatusObject</name>
    <message>
        <source>Online</source>
        <translation type="obsolete">На линия</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="obsolete">Извън линия</translation>
    </message>
</context>
</TS>

==> qutim_0.2.80-maemo-13.tar.gz: qutim-0.2.80-maemo/translations/bg_BG/vkontakte.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vkontakteplugin.cpp" line="+32"/>
        <source>Sidorov Aleksey</source>
        <translation>Алексей Сидоров</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/plugins/photoalbum/vphotoalbumplugin.cpp" line="+18"/>
        <location filename="../../qutim/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="+18"/>
        <source>Alexey Sidorov</source>
        <translation>Алексей Сидоров</translation>
    </message>
</context>
<context>
    <name>ContactInfo</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vinforequest.cpp" line="+62"/>
        <source>Nickname</source>
        <translation>Псевдоним</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>First name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Last name</source>
        <translation>Фамилия</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gender</source>
        <translation>Пол</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Birthday</source>
        <translation>Роден</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>City</source>
        <translation>Град</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Country</source>
        <translation>Държава</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Photo</source>
        <translation>Снимка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Home phone</source>
        <translation>Телефон (дом.)</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vcontact.cpp" line="+191"/>
        <location filename="../../qutim/protocols/vkontakte/src/vinforequest.cpp" line="+1"/>
        <source>Mobile phone</source>
        <translation>Телефон (моб.)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Activity</source>
        <translation>Дейност</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vinforequest.cpp" line="+1"/>
        <source>University</source>
        <translation>Университет</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Faculty</source>
        <translation>Факултет</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Graduation year</source>
        <translation>Година на завършване</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Undefined</source>
        <translation>Незададен</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Female</source>
        <translation>Жена</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Male</source>
        <translation>Мъж</translation>
    </message>
    <message>
        <location line="+111"/>
        <source>General</source>
        <translation>Обща</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Person</source>
        <translation>Човек</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Home address</source>
        <translation>Домашен адрес</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Education</source>
        <translation>Образование</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vkontakteplugin.cpp" line="-3"/>
        <source>Vkontakte</source>
        <translation>ВКонтакте</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Simple implementation of vkontakte, based on userapi.ru</source>
        <translation>Опростена реализация на ВКонтакте, на базата на userapi.ru</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>vkontakte</source>
        <translation>ВКонтакте</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Simple implementation of vkontakte, based on desktop.api</source>
        <translation>Опростена реализация на ВКонтакте, на базата на desktop.api</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Vkontakte account creator</source>
        <translation>Създаване на ВКонтакте сметка</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Account creator for Vkontakte</source>
        <translation>Създаване на сметка за ВКонтакте</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Proxy support</source>
        <translation>Поддръжка на прокси</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proxy support for Vkontakte</source>
        <translation>Поддръжка на прокси във ВКонтакте</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="-4"/>
        <source>Wall</source>
        <translation>Стена</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vkontakte wall support for qutIM</source>
        <translation>Поддръжка на ВКонтакте стена в qutIM</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/plugins/photoalbum/vphotoalbumplugin.cpp" line="-4"/>
        <source>Photoalbum</source>
        <translation>Фото албум</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vkontakte photoalbum support for qutIM</source>
        <translation>Поддръжка на ВКонтакте фото албум в qutIM</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="+4"/>
        <location filename="../../qutim/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="+4"/>
        <location filename="../../qutim/protocols/vkontakte/src/vkontakteplugin.cpp" line="-18"/>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
</context>
<context>
    <name>VAccountSettings</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/ui/vaccountsettings.ui" line="+14"/>
        <source>Account settings</source>
        <translation>Настройки на сметката</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Password:</source>
        <translation>Парола:</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/ui/vaccountsettings.cpp" line="+42"/>
        <source>%1 settings</source>
        <translation>%1 настройки</translation>
    </message>
</context>
<context>
    <name>VAccountWizardPage</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/ui/vaccountwizardpage.ui" line="+14"/>
        <source>WizardPage</source>
        <translation>Създаване на сметка</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Email:</source>
        <translation>Email:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Password:</source>
        <translation>Парола:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Save password</source>
        <translation>Запис на паролата</translation>
    </message>
</context>
<context>
    <name>VConnection</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vconnection.cpp" line="+96"/>
        <source>qutIM - VKontakte authorization</source>
        <translation>qutIM -ВКонтакте удостоверяване</translation>
    </message>
</context>
<context>
    <name>VWallSession</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/plugins/wall/vwallsession.cpp" line="+42"/>
        <source>%1 (Wall)</source>
        <translation>%1 (Стена)</translation>
    </message>
</context>
<context>
    <name>VWallSessionPrivate</name>
    <message>
        <location line="+129"/>
        <source>Unknown</source>
        <translation>Неизвестен</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Audio</source>
        <translation>Звуков</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Application</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Graffiti</source>
        <translation>Графити</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Photo</source>
        <translation>Снимка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Posted photo</source>
        <translation>Публикува снимка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Multimedia message: %1</source>
        <translation>Мултимедийно съобщение: %1</translation>
    </message>
</context>
<context>
    <name>Vkontakte</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vkontakteprotocol.cpp" line="+83"/>
        <source>Open homepage</source>
        <translation>Отваряне страницата</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/plugins/wall/vwallmanager.cpp" line="+9"/>
        <source>View wall</source>
        <translation>Преглед на всички</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vkontakteprotocol.cpp" line="+22"/>
        <source>Account settings</source>
        <translation>Настройки на сметката</translation>
    </message>
    <message>
        <location filename="../../qutim/protocols/vkontakte/plugins/photoalbum/vphotoalbumplugin.cpp" line="+10"/>
        <source>View photoalbum</source>
        <translation>Преглед на фото албума</translation>
    </message>
</context>
<context>
    <name>VkontakteProtocol</name>
    <message>
        <location filename="../../qutim/protocols/vkontakte/src/vkontakteprotocol.cpp" line="+8"/>
        <source>id</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VkontakteProtocolPrivate</name>
    <message>
        <location line="+29"/>
        <source>Send sms</source>
        <translation>Изпращане на SMS</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>text:</source>
        <translation>текст:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>sms</source>
        <translation>SMS</translation>
    </message>
</context>
</TS>
